// src/configs/chains.ts
var AssetChainMainnet = {
  id: 42420,
  name: "Asset Chain Mainnet",
  nativeCurrency: { name: "assetchain", symbol: "RWA", decimals: 18 },
  rpcUrls: {
    default: { http: ["https://mainnet-rpc.assetchain.org"] }
  },
  blockExplorers: {
    default: { name: "assetchain", url: "https://scan.assetchain.org" }
  }
};
var AssetChainTestnet = {
  id: 42421,
  name: "Asset Chain Testnet",
  nativeCurrency: { name: "assetchain", symbol: "RWA", decimals: 18 },
  rpcUrls: {
    default: { http: ["https://testnet-rpc.assetchain.org"] }
  },
  blockExplorers: {
    default: { name: "assetchain", url: "https://testnet-scan.assetchain.org" }
  }
};

// src/configs/networks.ts
var NETWORKS = {
  "assetchain_mainnet": {
    name: "Asset Chain Mainnet",
    addressType: "hex",
    chainId: 42420,
    currency: "RWA",
    explorerUrl: "https://scan.assetchain.org",
    rpcUrl: "https://mainnet-rpc.assetchain.org"
  },
  "assetchain_testnet": {
    name: "Asset Chain Testnet",
    addressType: "hex",
    chainId: 42421,
    currency: "RWA",
    explorerUrl: "https://testnet-scan.assetchain.org",
    rpcUrl: "https://testnet-rpc.assetchain.org"
  },
  "ton_mainnet": {
    name: "TON Mainnet",
    addressType: "base64",
    chainId: 1,
    currency: "TON",
    explorerUrl: "https://tonscan.org",
    rpcUrl: "https://ton-rpc.org"
  },
  "eth": {
    id: "eip155:1",
    chainNamespace: "eip155",
    name: "Ethereum",
    addressType: "hex",
    chainId: 1,
    currency: "ETH",
    explorerUrl: "https://etherscan.io",
    rpcUrl: "https://ethereum.org"
  }
};

// src/configs/index.ts
var configs = {
  NETWORKS,
  AssetChainMainnet,
  AssetChainTestnet
};

// src/pages/App.tsx
import { createContext, useEffect as useEffect3, useState as useState2 } from "react";

// src/utils/logConsole.tsx
var debugMode = false;
var logConsole = (...args) => {
  if (debugMode) {
    return console.log(...args);
  }
  return;
};

// src/hooks/useTonWallet.ts
import {
  useTonAddress,
  useTonConnectModal,
  useTonConnectUI
} from "@tonconnect/ui-react";
import { useContext, useEffect } from "react";
import TonWeb from "tonweb";
var tonWeb = new TonWeb();
var useTonWallet = () => {
  const { state, open, close } = useTonConnectModal();
  const [tonConnectUI] = useTonConnectUI();
  const userFriendlyAddress = useTonAddress();
  const rawAddress = useTonAddress(false);
  const dashboardContext = useContext(DashboardContext);
  if (!dashboardContext) {
    throw new Error("useDashboard Context must be used within a DashboardProvider");
  }
  const { tonConnected, setTonConnected, setSelectedWallet, setProcessing } = dashboardContext;
  const selectWallet = (wallet_) => {
    const wallet = wallet_.toLocaleLowerCase();
    logConsole({ wallet });
    if (wallet == "assetchain") {
      setSelectedWallet(NETWORKS.assetchain_mainnet);
    }
    if (wallet == "ton") {
      setSelectedWallet(NETWORKS.ton_mainnet);
    }
    if (wallet == "no_wallet") {
      setSelectedWallet();
    }
  };
  useEffect(() => {
    logConsole({ state });
    if (state.closeReason == "action-cancelled") {
      setTonConnected(false);
    }
    if (state.closeReason == "wallet-selected") {
      setTonConnected(true);
      selectWallet("ton");
    }
    if (state.closeReason == null && userFriendlyAddress.length) {
      setTonConnected(true);
    }
    if (state.closeReason == "action-cancelled" && !userFriendlyAddress.length) {
      setTonConnected(false);
      selectWallet("no_wallet");
    }
  }, [state]);
  const connectWallet = async () => {
    setProcessing(true);
    try {
      selectWallet("ton");
      await open();
      logConsole({ userFriendlyAddress, rawAddress });
    } catch (error) {
      logConsole({ error });
    }
    setProcessing(false);
  };
  const disconnectWallet = async () => {
    try {
      if (userFriendlyAddress.length) {
        await tonConnectUI.disconnect();
        await close();
        setTonConnected(false);
        setTonConnected(false);
        setSelectedWallet();
      } else {
        logConsole({ message: "Connect wallet" });
        setTonConnected(false);
      }
    } catch (error) {
      logConsole({ error });
    }
  };
  const sendTransaction2 = async (txParams) => {
    try {
      txParams.from = userFriendlyAddress;
      const value = tonWeb.utils.toNano(txParams.value);
      logConsole({ value });
      const tx = await tonConnectUI.sendTransaction({
        validUntil: Date.now() + 1e6,
        messages: [
          {
            address: txParams.to,
            amount: value.toString()
          }
        ]
      });
      return tx;
    } catch (error) {
      console.error("Transaction failed" + error.message);
    }
  };
  return {
    connectWallet,
    disconnectWallet,
    sendTransaction: sendTransaction2,
    userFriendlyAddress,
    tonConnected,
    state
  };
};

// src/hooks/useEvmWallet.ts
import { useEffect as useEffect2 } from "react";
import {
  getAccount,
  connect,
  disconnect,
  sendTransaction,
  reconnect,
  switchChain
} from "@wagmi/core";
import { parseEther, parseGwei } from "viem";

// src/configs/wagmiConfig.ts
import { http, createConfig, injected } from "@wagmi/core";
import { coinbaseWallet } from "@wagmi/connectors";
var coinBaseOptions = {
  appName: "Asset Chain Starter Kit"
};
var coinbaseConfig = coinbaseWallet(coinBaseOptions);
var wagmiConfig = createConfig({
  chains: [AssetChainMainnet, AssetChainTestnet],
  connectors: [coinbaseConfig, injected()],
  ssr: true,
  transports: {
    [AssetChainMainnet.id]: http(),
    [AssetChainTestnet.id]: http()
  }
});

// src/hooks/useEvmWallet.ts
import { metaMask, walletConnect } from "@wagmi/connectors";

// src/hooks/index.ts
import { useContext as useContext2 } from "react";
var useAssetChainConnect = () => {
  const context = useContext2(DashboardContext);
  if (!context) {
    throw new Error("useAssetChainConnect must be used within AssetChainKit");
  }
  return context;
};

// src/hooks/useEvmWallet.ts
var useEvmWallet = ({ projectId, infuraApiKey, metadata, network }) => {
  const metamaskOptions = {
    enableAnalytics: true,
    extensionOnly: false,
    infuraAPIKey: infuraApiKey,
    useDeeplink: true
  };
  const walletConnectOptions = {
    projectId,
    metadata,
    isNewChainsStale: true,
    disableProviderPing: false,
    customStoragePrefix: "wagmi",
    qrModalOptions: {
      themeMode: "light"
    }
  };
  const metaMaskConfig = metaMask(metamaskOptions);
  const walletConnectConfig = walletConnect(walletConnectOptions);
  const {
    address,
    chain,
    chainId,
    connector,
    isConnecting,
    status,
    isConnected
  } = getAccount(wagmiConfig);
  const defaultConnector = walletConnectConfig;
  const defaultChainId = network.id == 42420 ? AssetChainMainnet.id : AssetChainTestnet.id;
  const {
    evmConnected,
    setEvmConnected,
    setSelectedWallet,
    selectedWallet,
    setProcessing
  } = useAssetChainConnect();
  useEffect2(() => {
    logConsole({
      evmState: status,
      address,
      connector,
      isConnecting,
      isConnected
    });
    const wallet = status === "connected" || isConnected ? "assetchain" : "no_wallet";
    setEvmConnected(status === "connected" || isConnected);
    selectWallet(wallet);
  }, [status, isConnected]);
  const selectWallet = (wallet) => {
    switch (wallet.toLowerCase()) {
      case "assetchain":
        setSelectedWallet(NETWORKS.assetchain_mainnet);
        break;
      case "ton":
        setSelectedWallet(NETWORKS.ton_mainnet);
        break;
      default:
        setSelectedWallet(void 0);
    }
  };
  const connectEvmWallet = async () => {
    setProcessing(true);
    try {
      if (!isConnected) {
        logConsole("Connect EVM wallet");
        const result = await connect(wagmiConfig, { connector: defaultConnector, chainId: defaultChainId });
        if (result) {
          logConsole({ result });
          setEvmConnected(true);
          selectWallet("assetchain");
        }
      } else {
        logConsole("Wallet connected");
        selectWallet("assetchain");
      }
    } catch (error) {
      logConsole({ error });
    }
    setProcessing(false);
  };
  const disconnectEvmWallet = async () => {
    try {
      await disconnect(wagmiConfig);
      setEvmConnected(false);
    } catch (error) {
      logConsole({ error });
    }
  };
  const sendTransactionEvm = async (txParams) => {
    try {
      if (defaultChainId !== chainId) {
        logConsole("ChainId mismatch");
        await switchChain(wagmiConfig, { chainId: defaultChainId });
        return;
      }
      const result = await sendTransaction(wagmiConfig, {
        to: txParams.to,
        gas: parseGwei("20"),
        value: parseEther(txParams.value)
      });
      if (result) {
        logConsole({ sendTransactionEvm: result });
      }
      return result;
    } catch (error) {
      console.error({ error });
      logConsole("Something went wrong");
    }
  };
  const allowReconnect = async () => {
    try {
      const result = await reconnect(wagmiConfig, {
        connectors: [defaultConnector]
      });
      if (result) {
        logConsole({ allowReconnect: result });
      }
    } catch (error) {
      logConsole({ allowReconnectError: error });
    }
  };
  useEffect2(() => {
    if (!isConnected) {
      allowReconnect();
    }
  }, [isConnected]);
  return {
    connectEvmWallet,
    disconnectEvmWallet,
    sendTransactionEvm,
    evmAddress: address,
    isConnected,
    isConnecting
  };
};

// src/pages/App.tsx
import { QueryClient, QueryClientProvider } from "@tanstack/react-query";
import { WagmiProvider } from "wagmi";

// src/utils/concatAddress.ts
var concatAddress = (address) => address ? `${address.slice(0, 4)}...${address.slice(-4)}` : "";

// src/pages/Modal.tsx
import { Fragment, jsx, jsxs } from "react/jsx-runtime";

// src/pages/App.tsx
import { TonConnectUIProvider } from "@tonconnect/ui-react";
import { jsx as jsx2 } from "react/jsx-runtime";
var queryClientOptions = new QueryClient({
  defaultOptions: {
    queries: {
      gcTime: 1e3 * 60 * 60 * 24
    }
  }
});
var DashboardContext = createContext({
  tonConnected: false,
  setTonConnected: () => {
  },
  evmConnected: false,
  setEvmConnected: () => {
  },
  selectedWallet: {},
  setSelectedWallet: () => {
  },
  disableTon: false,
  setDisableTon: () => {
  },
  disableEvm: false,
  setDisableEvm: () => {
  },
  processing: false,
  setProcessing: () => {
  },
  isConnected: false,
  setIsConnected: () => {
  },
  walletConnected: false,
  setWalletConnected: () => {
  },
  handleSendTransaction: () => {
  },
  isConnecting: false,
  allowDisconnect: () => {
  },
  toggleModal: () => {
  },
  open: () => {
  },
  close: () => {
  },
  noTon: false,
  evmConnect: {
    connectEvmWallet: async () => {
    },
    disconnectEvmWallet: async () => {
    },
    sendTransactionEvm: async () => {
    },
    evmAddress: void 0,
    isConnected: false,
    isConnecting: false
  }
});

// src/pages/index.tsx
import { TonConnectUIProvider as TonConnectUIProvider2 } from "@tonconnect/ui-react";
import { jsx as jsx3 } from "react/jsx-runtime";

// src/utils/explorerLink.ts
function explorerLink(network, hash) {
  const rawLink = network.explorerUrl.concat("/tx/").concat(hash);
  const turncateLink = concatAddress(network.explorerUrl).concat("/tx/").concat(concatAddress(hash));
  return {
    rawLink,
    turncateLink
  };
}

// src/utils/onCopy.ts
var onCopy = async (text) => {
  try {
    await navigator.clipboard.writeText(text);
    console.log("Text copied");
  } catch (error) {
    console.log({ error });
  }
};

// src/utils/validateAddress.ts
function verifyAddress(address) {
  const hexRegex = /^0x[a-fA-F0-9]{40}$/;
  const base64Regex = /^[A-Za-z0-9+/=]{44}$/;
  if (hexRegex.test(address)) {
    return { address, type: "hex" };
  } else if (base64Regex.test(address)) {
    return { address, type: "base64" };
  } else {
    return { address, type: "invalid" };
  }
}

// src/test.ts
var sayHello = async () => {
  return "Asset Chain connect!";
};

// src/index.ts
import { TonConnectUIProvider as TonConnectUIProvider3 } from "@tonconnect/ui-react";
export {
  TonConnectUIProvider3 as TonConnectUIProvider,
  concatAddress,
  configs,
  explorerLink,
  onCopy,
  sayHello,
  useAssetChainConnect,
  useEvmWallet,
  useTonWallet,
  verifyAddress
};
